import type { Object3D } from 'three';
import { Vector3 } from 'three';
/**
 * 盒子空间
 */
export interface BoxSpace {
    top: number;
    bottom: number;
    left: number;
    right: number;
    front: number;
    back: number;
}
/**
 * 位置附近的对象查找器
 * @param position - 指定查找的位置
 * @returns 所有包含在指定空间的对象
 */
export type FindObjectsNearPosition = (position: Vector3) => Object3D[];
/**
 * 查找附近的对象
 * @param objs - 所有需要被查找的对象
 */
export type FindNearbyObjects = (objs: Object3D[]) => Object3D[];
/**
 *  创建 查找位置附近的 box 空间范围内的物体
 * @param boxSpace - 描述查找空间的信息对象
 * @param objects - 所有需要被查找的对象
 * @returns 用于查找的函数
 */
export declare function createFindObjectsInBoxNearPosition(boxSpace: BoxSpace, objects: Object3D[]): FindObjectsNearPosition;
/**
 *  创建 查找位置附近的球形空间范围内的物体
 *
 * @param radius - 描述查找半径
 * @param objects - 所有需要被查找的对象
 * @returns 用于查找的函数
 */
export declare function createFindObjectsInSphereNearPosition(radius: number, objects: Object3D[]): FindObjectsNearPosition;
/**
 *  创建 查找路径附近的范围内的物体
 *
 * @param points - 描述路径的点
 * @param radius - 描述查找半径
 * @returns 用于查找的函数
 */
export declare function createFindObjectsNearPath(points: Vector3[], radius: number): FindNearbyObjects;
